@@ -7,21 +7,21 @@
 #' @source \href{https://CRAN.R-project.org/package=roxygen2/vignettes/roxygen2.html}{roxygen2 formatting}
 #' @seealso \code{\link[base]{format}}
 #' @export
-#' @examples 
+#' @examples
 #' cat(tabular(mtcars[1:5, 1:5]))
 #' cat(tabular(mtcars[1:5, 1:5],header=FALSE))
 tabular <- function(df, header=TRUE, ...) {
   stopifnot(is.data.frame(df))
 
   align <- function(x) if (is.numeric(x)) "r" else "l"
-  
+
   col_align <- vapply(df, align, character(1))
 
   cols <- lapply(df, format, ...)
-  if(header) cols=lapply(names(cols),function(x) c(sprintf("\\strong{%s}",x),cols[[x]]))
-  cols[[1]]<-sprintf("  #' %s",cols[[1]])
-  
-  contents <- do.call("paste",c(cols, list(sep = " \\tab ", collapse = "\\cr\n  ")))
+  if (header) cols <- lapply(names(cols), function(x) c(sprintf("\\strong{%s}", x), cols[[x]]))
+  cols[[1]] <- sprintf("  #' %s", cols[[1]])
 
-  paste("#' \\tabular{", paste(col_align, collapse = ""), "}{\n  ",contents, "\n#'}\n", sep = "")
-}
\ No newline at end of file
+  contents <- do.call("paste", c(cols, list(sep = " \\tab ", collapse = "\\cr\n  ")))
+
+  paste("#' \\tabular{", paste(col_align, collapse = ""), "}{\n  ", contents, "\n#'}\n", sep = "")
+}
